@@ -1,11 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-12 22:41:09 mtw>
-
+# Last changed Time-stamp: <2015-02-24 14:01:47 mtw>
 
 package Bio::ViennaNGS::Util;
 
 use Exporter;
-use version; our $VERSION = qv('0.13');
+use version; our $VERSION = qv('0.14');
 use strict;
 use warnings;
 use Data::Dumper;
@@ -400,8 +399,10 @@ sub mkdircheck {
       $dir = dir(shift(@total)) unless (defined $dir);
       $dir = dir($dir,shift(@total));
     }
-    return if (-d $dir);
-    make_path($dir,{ verbose => 1 }) or croak "Error creating directory: $dir\t$, in $this_function!";
+    my $check = $dir->stringify();
+    return if (-d $check);
+    make_path($dir,{ verbose => 0 }) or
+      croak "ERROR [$this_function] Cannot create directory $check";
   }
 }
 
@@ -413,13 +414,15 @@ sub rmdircheck {
   }
   foreach (@dirstorm){
     my @total = split(/[\/\\]/,$_);
-    my $dir='';
+    my $dir;
     while(@total){
       $dir = dir(shift(@total)) unless (defined $dir);
       $dir = dir($dir,shift(@total));
     }
-    return if (!-d $dir);
-    remove_tree($dir,{ verbose => 1 }) or croak "Error deleting directory: $dir, in $this_function!";
+    my $check = $dir->stringify();
+    return if (!-d $check);
+    remove_tree($dir,{ verbose => 0 }) or
+      croak "ERROR [$this_function] Cannot remove directory $check";
   }
 }
 
