@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# Last changed Time-stamp: <2015-02-12 23:34:01 mtw>
+# Last changed Time-stamp: <2015-02-24 14:06:41 mtw>
 # AUTHOR: Joerg Fallmann <joerg.fallmann@univie.ac.at>
 
 ###############
@@ -82,12 +82,10 @@ throughout this tutorial:
 
 =item F<hg19_highlyexpressed.bed>
 
-=item F<hg19.chrom.sizes>
+=item F<hg19.chrom.sizes> (optional)
 
 =item F<C1R1.bam>
 
-=item F<hg19.chrom.sizes>
-
 =back
 
 We will assume that all input files are available and accessible in
@@ -111,7 +109,15 @@ hash.
   my $upstream    = 50;
   my $outfilebn   = $name.".ext".$upstream."_upstream";
   my $outfilebed  = $outfilebn.".bed";
+
+We now write out the sizes hash as hg19.chrom.sizes for later usage
+
   my %sizes       = %{fetch_chrom_sizes('hg19')};
+  open (CS,">","hg19.chrom.sizes"); 
+  foreach my $chrom (sort keys %sizes ){
+    print CS $chrom."\t".$sizes{$chrom}."\n";
+  }
+  close(CS);
 
 =cut
 
@@ -122,6 +128,12 @@ my $outfilebn   = $name.".ext".$upstream."_upstream";
 my $outfilebed  = $outfilebn.".bed";
 my %sizes       = %{fetch_chrom_sizes('hg19')}; ### Requires installation of UCSCs fetchChromSizes script or mysql
 
+open (CS,">","hg19.chrom.sizes"); ## Write out chrom.sizes.file for later usage
+foreach my $chrom (sort keys %sizes ){
+    print CS $chrom."\t".$sizes{$chrom}."\n";
+}
+close(CS);
+
 =head3 Generate a Bio::ViennaNGS::FeatureChain object
 
 We'll now parse our BED file of interest, generate a feature array and
@@ -147,7 +159,7 @@ potential promoter regions.
 
   my $extended_chain = extend_chain(\%sizes,$chain,$upstream,0,0,0);
 
-We'll also extend the entire U6 gene span 50nt upstream for later usage.
+We'll also extend the entire gene span 50nt upstream for later usage.
 
   my $extended_chain2 = extend_chain(\%sizes,$chain,$upstream,0,0,0);
 
